@@ -2,7 +2,7 @@ from abc import ABC
 
 
 class Sender(ABC):
-    def send_message(self, message: str | list) -> None:
+    def send_message(self, message: str) -> None:
         raise NotImplementedError("Method send_message not implemented yet")
 
     def send_image(self, image_path: str) -> None:
