@@ -21,4 +21,5 @@ class TelegramSender(Sender):
         self.bot.sendSticker(chat_id=self.chat_id, sticker=open(sticker_path, "rb"))
 
     def send_file(self, document_path: str):
-        self.bot.sendDocument(chat_id=self.chat_id, document=document_path)
+        with open(document_path, "rb") as file:
+            self.bot.sendDocument(chat_id=self.chat_id, document=file, filename=document_path)
